@@ -14,65 +14,126 @@ Usage::
     ```
 """
 
-from typing import Any, Dict, Mapping, Sequence, Type
+import sys
+from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import (
-    AuthenticationTypeType,
-    EnabledTypeType,
-    IdentityProviderTypeType,
-    InstanceTypeType,
-)
+from .paginator import ListSessionsPaginator
 from .type_defs import (
+    AssociateBrowserSettingsRequestRequestTypeDef,
     AssociateBrowserSettingsResponseTypeDef,
+    AssociateIpAccessSettingsRequestRequestTypeDef,
     AssociateIpAccessSettingsResponseTypeDef,
+    AssociateNetworkSettingsRequestRequestTypeDef,
     AssociateNetworkSettingsResponseTypeDef,
+    AssociateTrustStoreRequestRequestTypeDef,
     AssociateTrustStoreResponseTypeDef,
+    AssociateUserAccessLoggingSettingsRequestRequestTypeDef,
     AssociateUserAccessLoggingSettingsResponseTypeDef,
+    AssociateUserSettingsRequestRequestTypeDef,
     AssociateUserSettingsResponseTypeDef,
-    BlobTypeDef,
-    CookieSynchronizationConfigurationUnionTypeDef,
+    CreateBrowserSettingsRequestRequestTypeDef,
     CreateBrowserSettingsResponseTypeDef,
+    CreateIdentityProviderRequestRequestTypeDef,
     CreateIdentityProviderResponseTypeDef,
+    CreateIpAccessSettingsRequestRequestTypeDef,
     CreateIpAccessSettingsResponseTypeDef,
+    CreateNetworkSettingsRequestRequestTypeDef,
     CreateNetworkSettingsResponseTypeDef,
+    CreatePortalRequestRequestTypeDef,
     CreatePortalResponseTypeDef,
+    CreateTrustStoreRequestRequestTypeDef,
     CreateTrustStoreResponseTypeDef,
+    CreateUserAccessLoggingSettingsRequestRequestTypeDef,
     CreateUserAccessLoggingSettingsResponseTypeDef,
+    CreateUserSettingsRequestRequestTypeDef,
     CreateUserSettingsResponseTypeDef,
+    DeleteBrowserSettingsRequestRequestTypeDef,
+    DeleteIdentityProviderRequestRequestTypeDef,
+    DeleteIpAccessSettingsRequestRequestTypeDef,
+    DeleteNetworkSettingsRequestRequestTypeDef,
+    DeletePortalRequestRequestTypeDef,
+    DeleteTrustStoreRequestRequestTypeDef,
+    DeleteUserAccessLoggingSettingsRequestRequestTypeDef,
+    DeleteUserSettingsRequestRequestTypeDef,
+    DisassociateBrowserSettingsRequestRequestTypeDef,
+    DisassociateIpAccessSettingsRequestRequestTypeDef,
+    DisassociateNetworkSettingsRequestRequestTypeDef,
+    DisassociateTrustStoreRequestRequestTypeDef,
+    DisassociateUserAccessLoggingSettingsRequestRequestTypeDef,
+    DisassociateUserSettingsRequestRequestTypeDef,
+    ExpireSessionRequestRequestTypeDef,
+    GetBrowserSettingsRequestRequestTypeDef,
     GetBrowserSettingsResponseTypeDef,
+    GetIdentityProviderRequestRequestTypeDef,
     GetIdentityProviderResponseTypeDef,
+    GetIpAccessSettingsRequestRequestTypeDef,
     GetIpAccessSettingsResponseTypeDef,
+    GetNetworkSettingsRequestRequestTypeDef,
     GetNetworkSettingsResponseTypeDef,
+    GetPortalRequestRequestTypeDef,
     GetPortalResponseTypeDef,
+    GetPortalServiceProviderMetadataRequestRequestTypeDef,
     GetPortalServiceProviderMetadataResponseTypeDef,
+    GetSessionRequestRequestTypeDef,
+    GetSessionResponseTypeDef,
+    GetTrustStoreCertificateRequestRequestTypeDef,
     GetTrustStoreCertificateResponseTypeDef,
+    GetTrustStoreRequestRequestTypeDef,
     GetTrustStoreResponseTypeDef,
+    GetUserAccessLoggingSettingsRequestRequestTypeDef,
     GetUserAccessLoggingSettingsResponseTypeDef,
+    GetUserSettingsRequestRequestTypeDef,
     GetUserSettingsResponseTypeDef,
-    IpRuleTypeDef,
+    ListBrowserSettingsRequestRequestTypeDef,
     ListBrowserSettingsResponseTypeDef,
+    ListIdentityProvidersRequestRequestTypeDef,
     ListIdentityProvidersResponseTypeDef,
+    ListIpAccessSettingsRequestRequestTypeDef,
     ListIpAccessSettingsResponseTypeDef,
+    ListNetworkSettingsRequestRequestTypeDef,
     ListNetworkSettingsResponseTypeDef,
+    ListPortalsRequestRequestTypeDef,
     ListPortalsResponseTypeDef,
+    ListSessionsRequestRequestTypeDef,
+    ListSessionsResponseTypeDef,
+    ListTagsForResourceRequestRequestTypeDef,
     ListTagsForResourceResponseTypeDef,
+    ListTrustStoreCertificatesRequestRequestTypeDef,
     ListTrustStoreCertificatesResponseTypeDef,
+    ListTrustStoresRequestRequestTypeDef,
     ListTrustStoresResponseTypeDef,
+    ListUserAccessLoggingSettingsRequestRequestTypeDef,
     ListUserAccessLoggingSettingsResponseTypeDef,
+    ListUserSettingsRequestRequestTypeDef,
     ListUserSettingsResponseTypeDef,
-    TagTypeDef,
+    TagResourceRequestRequestTypeDef,
+    UntagResourceRequestRequestTypeDef,
+    UpdateBrowserSettingsRequestRequestTypeDef,
     UpdateBrowserSettingsResponseTypeDef,
+    UpdateIdentityProviderRequestRequestTypeDef,
     UpdateIdentityProviderResponseTypeDef,
+    UpdateIpAccessSettingsRequestRequestTypeDef,
     UpdateIpAccessSettingsResponseTypeDef,
+    UpdateNetworkSettingsRequestRequestTypeDef,
     UpdateNetworkSettingsResponseTypeDef,
+    UpdatePortalRequestRequestTypeDef,
     UpdatePortalResponseTypeDef,
+    UpdateTrustStoreRequestRequestTypeDef,
     UpdateTrustStoreResponseTypeDef,
+    UpdateUserAccessLoggingSettingsRequestRequestTypeDef,
     UpdateUserAccessLoggingSettingsResponseTypeDef,
+    UpdateUserSettingsRequestRequestTypeDef,
     UpdateUserSettingsResponseTypeDef,
 )
 
+if sys.version_info >= (3, 12):
+    from typing import Literal, Unpack
+else:
+    from typing_extensions import Literal, Unpack
+
+
 __all__ = ("WorkSpacesWebClient",)
 
 
@@ -114,7 +175,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_browser_settings(
-        self, *, browserSettingsArn: str, portalArn: str
+        self, **kwargs: Unpack[AssociateBrowserSettingsRequestRequestTypeDef]
     ) -> AssociateBrowserSettingsResponseTypeDef:
         """
         Associates a browser settings resource with a web portal.
@@ -124,7 +185,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_ip_access_settings(
-        self, *, ipAccessSettingsArn: str, portalArn: str
+        self, **kwargs: Unpack[AssociateIpAccessSettingsRequestRequestTypeDef]
     ) -> AssociateIpAccessSettingsResponseTypeDef:
         """
         Associates an IP access settings resource with a web portal.
@@ -134,7 +195,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_network_settings(
-        self, *, networkSettingsArn: str, portalArn: str
+        self, **kwargs: Unpack[AssociateNetworkSettingsRequestRequestTypeDef]
     ) -> AssociateNetworkSettingsResponseTypeDef:
         """
         Associates a network settings resource with a web portal.
@@ -144,7 +205,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_trust_store(
-        self, *, portalArn: str, trustStoreArn: str
+        self, **kwargs: Unpack[AssociateTrustStoreRequestRequestTypeDef]
     ) -> AssociateTrustStoreResponseTypeDef:
         """
         Associates a trust store with a web portal.
@@ -154,7 +215,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_user_access_logging_settings(
-        self, *, portalArn: str, userAccessLoggingSettingsArn: str
+        self, **kwargs: Unpack[AssociateUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> AssociateUserAccessLoggingSettingsResponseTypeDef:
         """
         Associates a user access logging settings resource with a web portal.
@@ -164,7 +225,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def associate_user_settings(
-        self, *, portalArn: str, userSettingsArn: str
+        self, **kwargs: Unpack[AssociateUserSettingsRequestRequestTypeDef]
     ) -> AssociateUserSettingsResponseTypeDef:
         """
         Associates a user settings resource with a web portal.
@@ -190,13 +251,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_browser_settings(
-        self,
-        *,
-        browserPolicy: str,
-        additionalEncryptionContext: Mapping[str, str] = ...,
-        clientToken: str = ...,
-        customerManagedKey: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateBrowserSettingsRequestRequestTypeDef]
     ) -> CreateBrowserSettingsResponseTypeDef:
         """
         Creates a browser settings resource that can be associated with a web portal.
@@ -206,14 +261,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_identity_provider(
-        self,
-        *,
-        identityProviderDetails: Mapping[str, str],
-        identityProviderName: str,
-        identityProviderType: IdentityProviderTypeType,
-        portalArn: str,
-        clientToken: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateIdentityProviderRequestRequestTypeDef]
     ) -> CreateIdentityProviderResponseTypeDef:
         """
         Creates an identity provider resource that is then associated with a web portal.
@@ -223,15 +271,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_ip_access_settings(
-        self,
-        *,
-        ipRules: Sequence[IpRuleTypeDef],
-        additionalEncryptionContext: Mapping[str, str] = ...,
-        clientToken: str = ...,
-        customerManagedKey: str = ...,
-        description: str = ...,
-        displayName: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateIpAccessSettingsRequestRequestTypeDef]
     ) -> CreateIpAccessSettingsResponseTypeDef:
         """
         Creates an IP access settings resource that can be associated with a web portal.
@@ -241,13 +281,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_network_settings(
-        self,
-        *,
-        securityGroupIds: Sequence[str],
-        subnetIds: Sequence[str],
-        vpcId: str,
-        clientToken: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateNetworkSettingsRequestRequestTypeDef]
     ) -> CreateNetworkSettingsResponseTypeDef:
         """
         Creates a network settings resource that can be associated with a web portal.
@@ -257,16 +291,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_portal(
-        self,
-        *,
-        additionalEncryptionContext: Mapping[str, str] = ...,
-        authenticationType: AuthenticationTypeType = ...,
-        clientToken: str = ...,
-        customerManagedKey: str = ...,
-        displayName: str = ...,
-        instanceType: InstanceTypeType = ...,
-        maxConcurrentSessions: int = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreatePortalRequestRequestTypeDef]
     ) -> CreatePortalResponseTypeDef:
         """
         Creates a web portal.
@@ -276,11 +301,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_trust_store(
-        self,
-        *,
-        certificateList: Sequence[BlobTypeDef],
-        clientToken: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateTrustStoreRequestRequestTypeDef]
     ) -> CreateTrustStoreResponseTypeDef:
         """
         Creates a trust store that can be associated with a web portal.
@@ -290,7 +311,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_user_access_logging_settings(
-        self, *, kinesisStreamArn: str, clientToken: str = ..., tags: Sequence[TagTypeDef] = ...
+        self, **kwargs: Unpack[CreateUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> CreateUserAccessLoggingSettingsResponseTypeDef:
         """
         Creates a user access logging settings resource that can be associated with a
@@ -302,21 +323,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def create_user_settings(
-        self,
-        *,
-        copyAllowed: EnabledTypeType,
-        downloadAllowed: EnabledTypeType,
-        pasteAllowed: EnabledTypeType,
-        printAllowed: EnabledTypeType,
-        uploadAllowed: EnabledTypeType,
-        additionalEncryptionContext: Mapping[str, str] = ...,
-        clientToken: str = ...,
-        cookieSynchronizationConfiguration: CookieSynchronizationConfigurationUnionTypeDef = ...,
-        customerManagedKey: str = ...,
-        deepLinkAllowed: EnabledTypeType = ...,
-        disconnectTimeoutInMinutes: int = ...,
-        idleDisconnectTimeoutInMinutes: int = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateUserSettingsRequestRequestTypeDef]
     ) -> CreateUserSettingsResponseTypeDef:
         """
         Creates a user settings resource that can be associated with a web portal.
@@ -325,7 +332,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_user_settings)
         """
 
-    def delete_browser_settings(self, *, browserSettingsArn: str) -> Dict[str, Any]:
+    def delete_browser_settings(
+        self, **kwargs: Unpack[DeleteBrowserSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes browser settings.
 
@@ -333,7 +342,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_browser_settings)
         """
 
-    def delete_identity_provider(self, *, identityProviderArn: str) -> Dict[str, Any]:
+    def delete_identity_provider(
+        self, **kwargs: Unpack[DeleteIdentityProviderRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes the identity provider.
 
@@ -341,7 +352,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_identity_provider)
         """
 
-    def delete_ip_access_settings(self, *, ipAccessSettingsArn: str) -> Dict[str, Any]:
+    def delete_ip_access_settings(
+        self, **kwargs: Unpack[DeleteIpAccessSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes IP access settings.
 
@@ -349,7 +362,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_ip_access_settings)
         """
 
-    def delete_network_settings(self, *, networkSettingsArn: str) -> Dict[str, Any]:
+    def delete_network_settings(
+        self, **kwargs: Unpack[DeleteNetworkSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes network settings.
 
@@ -357,7 +372,7 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_network_settings)
         """
 
-    def delete_portal(self, *, portalArn: str) -> Dict[str, Any]:
+    def delete_portal(self, **kwargs: Unpack[DeletePortalRequestRequestTypeDef]) -> Dict[str, Any]:
         """
         Deletes a web portal.
 
@@ -365,7 +380,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_portal)
         """
 
-    def delete_trust_store(self, *, trustStoreArn: str) -> Dict[str, Any]:
+    def delete_trust_store(
+        self, **kwargs: Unpack[DeleteTrustStoreRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes the trust store.
 
@@ -374,7 +391,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def delete_user_access_logging_settings(
-        self, *, userAccessLoggingSettingsArn: str
+        self, **kwargs: Unpack[DeleteUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> Dict[str, Any]:
         """
         Deletes user access logging settings.
@@ -383,7 +400,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_user_access_logging_settings)
         """
 
-    def delete_user_settings(self, *, userSettingsArn: str) -> Dict[str, Any]:
+    def delete_user_settings(
+        self, **kwargs: Unpack[DeleteUserSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes user settings.
 
@@ -391,7 +410,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_user_settings)
         """
 
-    def disassociate_browser_settings(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_browser_settings(
+        self, **kwargs: Unpack[DisassociateBrowserSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates browser settings from a web portal.
 
@@ -399,7 +420,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_browser_settings)
         """
 
-    def disassociate_ip_access_settings(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_ip_access_settings(
+        self, **kwargs: Unpack[DisassociateIpAccessSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates IP access settings from a web portal.
 
@@ -407,7 +430,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_ip_access_settings)
         """
 
-    def disassociate_network_settings(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_network_settings(
+        self, **kwargs: Unpack[DisassociateNetworkSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates network settings from a web portal.
 
@@ -415,7 +440,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_network_settings)
         """
 
-    def disassociate_trust_store(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_trust_store(
+        self, **kwargs: Unpack[DisassociateTrustStoreRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates a trust store from a web portal.
 
@@ -423,7 +450,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_trust_store)
         """
 
-    def disassociate_user_access_logging_settings(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_user_access_logging_settings(
+        self, **kwargs: Unpack[DisassociateUserAccessLoggingSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates user access logging settings from a web portal.
 
@@ -431,7 +460,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_user_access_logging_settings)
         """
 
-    def disassociate_user_settings(self, *, portalArn: str) -> Dict[str, Any]:
+    def disassociate_user_settings(
+        self, **kwargs: Unpack[DisassociateUserSettingsRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Disassociates user settings from a web portal.
 
@@ -439,6 +470,16 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_user_settings)
         """
 
+    def expire_session(
+        self, **kwargs: Unpack[ExpireSessionRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
+        """
+        Expires an active secure browser session.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.expire_session)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#expire_session)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -453,7 +494,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#generate_presigned_url)
         """
 
-    def get_browser_settings(self, *, browserSettingsArn: str) -> GetBrowserSettingsResponseTypeDef:
+    def get_browser_settings(
+        self, **kwargs: Unpack[GetBrowserSettingsRequestRequestTypeDef]
+    ) -> GetBrowserSettingsResponseTypeDef:
         """
         Gets browser settings.
 
@@ -462,7 +505,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def get_identity_provider(
-        self, *, identityProviderArn: str
+        self, **kwargs: Unpack[GetIdentityProviderRequestRequestTypeDef]
     ) -> GetIdentityProviderResponseTypeDef:
         """
         Gets the identity provider.
@@ -472,7 +515,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def get_ip_access_settings(
-        self, *, ipAccessSettingsArn: str
+        self, **kwargs: Unpack[GetIpAccessSettingsRequestRequestTypeDef]
     ) -> GetIpAccessSettingsResponseTypeDef:
         """
         Gets the IP access settings.
@@ -481,7 +524,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_ip_access_settings)
         """
 
-    def get_network_settings(self, *, networkSettingsArn: str) -> GetNetworkSettingsResponseTypeDef:
+    def get_network_settings(
+        self, **kwargs: Unpack[GetNetworkSettingsRequestRequestTypeDef]
+    ) -> GetNetworkSettingsResponseTypeDef:
         """
         Gets the network settings.
 
@@ -489,7 +534,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_network_settings)
         """
 
-    def get_portal(self, *, portalArn: str) -> GetPortalResponseTypeDef:
+    def get_portal(
+        self, **kwargs: Unpack[GetPortalRequestRequestTypeDef]
+    ) -> GetPortalResponseTypeDef:
         """
         Gets the web portal.
 
@@ -498,7 +545,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def get_portal_service_provider_metadata(
-        self, *, portalArn: str
+        self, **kwargs: Unpack[GetPortalServiceProviderMetadataRequestRequestTypeDef]
     ) -> GetPortalServiceProviderMetadataResponseTypeDef:
         """
         Gets the service provider metadata.
@@ -507,7 +554,19 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_portal_service_provider_metadata)
         """
 
-    def get_trust_store(self, *, trustStoreArn: str) -> GetTrustStoreResponseTypeDef:
+    def get_session(
+        self, **kwargs: Unpack[GetSessionRequestRequestTypeDef]
+    ) -> GetSessionResponseTypeDef:
+        """
+        Gets information for a secure browser session.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_session)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_session)
+        """
+
+    def get_trust_store(
+        self, **kwargs: Unpack[GetTrustStoreRequestRequestTypeDef]
+    ) -> GetTrustStoreResponseTypeDef:
         """
         Gets the trust store.
 
@@ -516,7 +575,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def get_trust_store_certificate(
-        self, *, thumbprint: str, trustStoreArn: str
+        self, **kwargs: Unpack[GetTrustStoreCertificateRequestRequestTypeDef]
     ) -> GetTrustStoreCertificateResponseTypeDef:
         """
         Gets the trust store certificate.
@@ -526,7 +585,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def get_user_access_logging_settings(
-        self, *, userAccessLoggingSettingsArn: str
+        self, **kwargs: Unpack[GetUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> GetUserAccessLoggingSettingsResponseTypeDef:
         """
         Gets user access logging settings.
@@ -535,7 +594,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_user_access_logging_settings)
         """
 
-    def get_user_settings(self, *, userSettingsArn: str) -> GetUserSettingsResponseTypeDef:
+    def get_user_settings(
+        self, **kwargs: Unpack[GetUserSettingsRequestRequestTypeDef]
+    ) -> GetUserSettingsResponseTypeDef:
         """
         Gets user settings.
 
@@ -544,7 +605,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_browser_settings(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListBrowserSettingsRequestRequestTypeDef]
     ) -> ListBrowserSettingsResponseTypeDef:
         """
         Retrieves a list of browser settings.
@@ -554,7 +615,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_identity_providers(
-        self, *, portalArn: str, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListIdentityProvidersRequestRequestTypeDef]
     ) -> ListIdentityProvidersResponseTypeDef:
         """
         Retrieves a list of identity providers for a specific web portal.
@@ -564,7 +625,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_ip_access_settings(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListIpAccessSettingsRequestRequestTypeDef]
     ) -> ListIpAccessSettingsResponseTypeDef:
         """
         Retrieves a list of IP access settings.
@@ -574,7 +635,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_network_settings(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListNetworkSettingsRequestRequestTypeDef]
     ) -> ListNetworkSettingsResponseTypeDef:
         """
         Retrieves a list of network settings.
@@ -584,7 +645,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_portals(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListPortalsRequestRequestTypeDef]
     ) -> ListPortalsResponseTypeDef:
         """
         Retrieves a list or web portals.
@@ -593,7 +654,19 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_portals)
         """
 
-    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_sessions(
+        self, **kwargs: Unpack[ListSessionsRequestRequestTypeDef]
+    ) -> ListSessionsResponseTypeDef:
+        """
+        Lists information for multiple secure browser sessions from a specific portal.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_sessions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_sessions)
+        """
+
+    def list_tags_for_resource(
+        self, **kwargs: Unpack[ListTagsForResourceRequestRequestTypeDef]
+    ) -> ListTagsForResourceResponseTypeDef:
         """
         Retrieves a list of tags for a resource.
 
@@ -602,7 +675,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_trust_store_certificates(
-        self, *, trustStoreArn: str, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListTrustStoreCertificatesRequestRequestTypeDef]
     ) -> ListTrustStoreCertificatesResponseTypeDef:
         """
         Retrieves a list of trust store certificates.
@@ -612,7 +685,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_trust_stores(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListTrustStoresRequestRequestTypeDef]
     ) -> ListTrustStoresResponseTypeDef:
         """
         Retrieves a list of trust stores.
@@ -622,7 +695,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_user_access_logging_settings(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> ListUserAccessLoggingSettingsResponseTypeDef:
         """
         Retrieves a list of user access logging settings.
@@ -632,7 +705,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def list_user_settings(
-        self, *, maxResults: int = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListUserSettingsRequestRequestTypeDef]
     ) -> ListUserSettingsResponseTypeDef:
         """
         Retrieves a list of user settings.
@@ -641,9 +714,7 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_user_settings)
         """
 
-    def tag_resource(
-        self, *, resourceArn: str, tags: Sequence[TagTypeDef], clientToken: str = ...
-    ) -> Dict[str, Any]:
+    def tag_resource(self, **kwargs: Unpack[TagResourceRequestRequestTypeDef]) -> Dict[str, Any]:
         """
         Adds or overwrites one or more tags for the specified resource.
 
@@ -651,7 +722,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
+    def untag_resource(
+        self, **kwargs: Unpack[UntagResourceRequestRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Removes one or more tags from the specified resource.
 
@@ -660,7 +733,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_browser_settings(
-        self, *, browserSettingsArn: str, browserPolicy: str = ..., clientToken: str = ...
+        self, **kwargs: Unpack[UpdateBrowserSettingsRequestRequestTypeDef]
     ) -> UpdateBrowserSettingsResponseTypeDef:
         """
         Updates browser settings.
@@ -670,13 +743,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_identity_provider(
-        self,
-        *,
-        identityProviderArn: str,
-        clientToken: str = ...,
-        identityProviderDetails: Mapping[str, str] = ...,
-        identityProviderName: str = ...,
-        identityProviderType: IdentityProviderTypeType = ...,
+        self, **kwargs: Unpack[UpdateIdentityProviderRequestRequestTypeDef]
     ) -> UpdateIdentityProviderResponseTypeDef:
         """
         Updates the identity provider.
@@ -686,13 +753,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_ip_access_settings(
-        self,
-        *,
-        ipAccessSettingsArn: str,
-        clientToken: str = ...,
-        description: str = ...,
-        displayName: str = ...,
-        ipRules: Sequence[IpRuleTypeDef] = ...,
+        self, **kwargs: Unpack[UpdateIpAccessSettingsRequestRequestTypeDef]
     ) -> UpdateIpAccessSettingsResponseTypeDef:
         """
         Updates IP access settings.
@@ -702,13 +763,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_network_settings(
-        self,
-        *,
-        networkSettingsArn: str,
-        clientToken: str = ...,
-        securityGroupIds: Sequence[str] = ...,
-        subnetIds: Sequence[str] = ...,
-        vpcId: str = ...,
+        self, **kwargs: Unpack[UpdateNetworkSettingsRequestRequestTypeDef]
     ) -> UpdateNetworkSettingsResponseTypeDef:
         """
         Updates network settings.
@@ -718,13 +773,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_portal(
-        self,
-        *,
-        portalArn: str,
-        authenticationType: AuthenticationTypeType = ...,
-        displayName: str = ...,
-        instanceType: InstanceTypeType = ...,
-        maxConcurrentSessions: int = ...,
+        self, **kwargs: Unpack[UpdatePortalRequestRequestTypeDef]
     ) -> UpdatePortalResponseTypeDef:
         """
         Updates a web portal.
@@ -734,12 +783,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_trust_store(
-        self,
-        *,
-        trustStoreArn: str,
-        certificatesToAdd: Sequence[BlobTypeDef] = ...,
-        certificatesToDelete: Sequence[str] = ...,
-        clientToken: str = ...,
+        self, **kwargs: Unpack[UpdateTrustStoreRequestRequestTypeDef]
     ) -> UpdateTrustStoreResponseTypeDef:
         """
         Updates the trust store.
@@ -749,11 +793,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_user_access_logging_settings(
-        self,
-        *,
-        userAccessLoggingSettingsArn: str,
-        clientToken: str = ...,
-        kinesisStreamArn: str = ...,
+        self, **kwargs: Unpack[UpdateUserAccessLoggingSettingsRequestRequestTypeDef]
     ) -> UpdateUserAccessLoggingSettingsResponseTypeDef:
         """
         Updates the user access logging settings.
@@ -763,19 +803,7 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_user_settings(
-        self,
-        *,
-        userSettingsArn: str,
-        clientToken: str = ...,
-        cookieSynchronizationConfiguration: CookieSynchronizationConfigurationUnionTypeDef = ...,
-        copyAllowed: EnabledTypeType = ...,
-        deepLinkAllowed: EnabledTypeType = ...,
-        disconnectTimeoutInMinutes: int = ...,
-        downloadAllowed: EnabledTypeType = ...,
-        idleDisconnectTimeoutInMinutes: int = ...,
-        pasteAllowed: EnabledTypeType = ...,
-        printAllowed: EnabledTypeType = ...,
-        uploadAllowed: EnabledTypeType = ...,
+        self, **kwargs: Unpack[UpdateUserSettingsRequestRequestTypeDef]
     ) -> UpdateUserSettingsResponseTypeDef:
         """
         Updates the user settings.
@@ -783,3 +811,9 @@ class WorkSpacesWebClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_user_settings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_user_settings)
         """
+
+    def get_paginator(self, operation_name: Literal["list_sessions"]) -> ListSessionsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_paginator)
+        """
